@@ -191,7 +191,7 @@ class CfnEnvironmentEC2(
                 image_id: typing.Optional[builtins.str] = None,
                 name: typing.Optional[builtins.str] = None,
                 owner_arn: typing.Optional[builtins.str] = None,
-                repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnEnvironmentEC2.RepositoryProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
+                repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
                 subnet_id: typing.Optional[builtins.str] = None,
                 tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
             ) -> None:
@@ -444,7 +444,7 @@ class CfnEnvironmentEC2(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]],
+                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, aws_cdk.core.IResolvable]]]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
